# Contributing Guidelines

Thank you for considering contributing to **CImpact**! We welcome contributions from the community to make this library better.

## How Can You Contribute?

### Reporting Bugs

- **Search Existing Issues**: Before opening a new issue, please check if it has already been reported.
- **Create a New Issue**: If you find a bug, please create an issue with detailed information:
  - Steps to reproduce the bug.
  - Expected behavior.
  - Actual behavior.
  - Any relevant logs or screenshots.

### Suggesting Enhancements

- **Feature Requests**: We are open to new ideas! Please create an issue with:
  - A clear and descriptive title.
  - A detailed description of the proposed enhancement.
  - Any examples or use cases where this feature would be beneficial.

### Submitting Pull Requests

- **Fork the Repository**: Create a personal fork of the repository on GitHub.
- **Clone the Fork**: Clone your fork to your local machine.
- **Create a Branch**: Create a new branch for your changes.
  - Use a descriptive branch name (e.g., `feature/model-extension` or `bugfix/data-loading`).
- **Make Changes**: Implement your changes or additions.
  - Follow the existing code style and conventions.
  - Write clear and concise code.
- **Add Tests**: If applicable, add unit tests to cover your changes.
- **Commit Changes**: Commit your changes with a meaningful commit message.
- **Push to Fork**: Push your branch to your forked repository on GitHub.
- **Submit a Pull Request**: Open a pull request to the `main` branch of the original repository.
  - Provide a clear description of the changes.
  - Reference any related issues.

### Code Style Guidelines

- **PEP 8**: Adhere to [PEP 8](https://www.python.org/dev/peps/pep-0008/) coding style.
- **Type Annotations**: Use type annotations where appropriate.
- **Comments and Docstrings**: Write clear comments and docstrings for functions and classes.

### Testing

- **Unit Tests**: Ensure that all existing tests pass and add new tests for your changes.
- **Testing Framework**: Use `pytest` or the existing testing framework in the project.
- **Coverage**: Aim for high code coverage.

## Community Guidelines

- **Be Respectful**: Maintain a friendly and respectful environment.
- **Collaboration**: Be open to feedback and discussions.
- **Acknowledgements**: Contributors will be acknowledged in the project's documentation.

## Getting Help

If you have any questions or need assistance, feel free to open an issue or reach out to the maintainers.

## License Agreement

By contributing to this project, you agree that your contributions will be licensed under the same license as the project.

---

We appreciate your time and effort in contributing to CImpact!
